# ngobot_json
The repository contain a script to format your method's response in a correct JSON format using the standard HTTP response codes. Well suitable to backend applications with REST API building concept in mind.
